summaryrefslogtreecommitdiffstats
path: root/templates
diff options
context:
space:
mode:
Diffstat (limited to 'templates')
-rw-r--r--templates/annotated/basicapp.py8
-rw-r--r--templates/annotated/menuapp1.py10
-rw-r--r--templates/annotated/menuapp2.py6
-rw-r--r--templates/annotated/menuapp3.py6
-rw-r--r--templates/annotated/systray1.py2
-rw-r--r--templates/basic/basicapp.py4
-rw-r--r--templates/basic/menuapp1.py6
-rw-r--r--templates/basic/menuapp2.py6
-rw-r--r--templates/basic/menuapp3.py6
9 files changed, 27 insertions, 27 deletions
diff --git a/templates/annotated/menuapp2.py b/templates/annotated/menuapp2.py
index c5cbe1b..1924eef 100644
--- a/templates/annotated/menuapp2.py
+++ b/templates/annotated/menuapp2.py
@@ -43,7 +43,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, i18n
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n
from tdeui import KMainWindow, KMessageBox, KStdAction, KAction
STATUSBAR_LEFT = 1
@@ -234,9 +234,9 @@ aboutData = KAboutData ("", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/templates/annotated/menuapp3.py b/templates/annotated/menuapp3.py
index 19140ef..84a90f7 100644
--- a/templates/annotated/menuapp3.py
+++ b/templates/annotated/menuapp3.py
@@ -43,7 +43,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, i18n
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n
from tdeui import KMainWindow, KMessageBox, KStdAction, KAction, KActionCollection
STATUSBAR_LEFT = 1
@@ -198,9 +198,9 @@ aboutData = KAboutData ("menuapp3", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/templates/annotated/systray1.py b/templates/annotated/systray1.py
index 1537fbc..db017c3 100644
--- a/templates/annotated/systray1.py
+++ b/templates/annotated/systray1.py
@@ -74,7 +74,7 @@ class MainWin (KMainWindow):
#-------------------- main ------------------------------------------------
-# The usual stuff - you can also use the KAboutData/KCmdLineArgs version
+# The usual stuff - you can also use the KAboutData/TDECmdLineArgs version
# for program startup used in other templates - the TDEApplication constructor
# used here may be obsoleted eventually
appName = "template"
diff --git a/templates/basic/basicapp.py b/templates/basic/basicapp.py
index b5b5f62..01ce1af 100644
--- a/templates/basic/basicapp.py
+++ b/templates/basic/basicapp.py
@@ -30,7 +30,7 @@ copyright holder.
import sys
from qt import SIGNAL
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData
from tdeui import KMainWindow
class MainWin (KMainWindow):
@@ -49,7 +49,7 @@ aboutData = KAboutData ("", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/templates/basic/menuapp1.py b/templates/basic/menuapp1.py
index 4b33bda..7809cef 100644
--- a/templates/basic/menuapp1.py
+++ b/templates/basic/menuapp1.py
@@ -44,7 +44,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, i18n, KStdAccel, KIcon, KIconLoader
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n, KStdAccel, KIcon, KIconLoader
from tdeui import KMainWindow, KMessageBox
TOOLBAR_NEW = 1
@@ -184,9 +184,9 @@ aboutData = KAboutData ("", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/templates/basic/menuapp2.py b/templates/basic/menuapp2.py
index 54d3593..f765692 100644
--- a/templates/basic/menuapp2.py
+++ b/templates/basic/menuapp2.py
@@ -43,7 +43,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, i18n, KShortcut
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n, KShortcut
from tdeui import KMainWindow, KMessageBox, KStdAction, KAction
STATUSBAR_LEFT = 1
@@ -190,9 +190,9 @@ aboutData = KAboutData ("", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/templates/basic/menuapp3.py b/templates/basic/menuapp3.py
index e3328bc..9051661 100644
--- a/templates/basic/menuapp3.py
+++ b/templates/basic/menuapp3.py
@@ -43,7 +43,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, i18n, KShortcut
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n, KShortcut
from tdeui import KMainWindow, KMessageBox, KStdAction, KAction, KActionCollection
STATUSBAR_LEFT = 1
@@ -151,9 +151,9 @@ aboutData = KAboutData ("menuapp3", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/templates/annotated/basicapp.py b/templates/annotated/basicapp.py
index 44b6681..b5abe80 100644
--- a/templates/annotated/basicapp.py
+++ b/templates/annotated/basicapp.py
@@ -35,7 +35,7 @@ copyright holder.
import sys
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData
from tdeui import KMainWindow
"""
@@ -75,7 +75,7 @@ aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
# Pass the command line arguments and aboutData to
# KCmdLineArgs - this is where KDE will look for
# this information. The TDEApplication constructor
# used below *requires* the args are processed
# *before* TDEApplication is instantiated. There
@@ -85,7 +85,7 @@ aboutData.addAuthor ("author2", "they did something else", "another@email.addres
# Note that instead of argc/argv, this constructor
# only takes a single argument - sys.argv - which
# is a Python list
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
# Set up the command line options (switches) you
# want your app to be able to process (you could
@@ -94,7 +94,7 @@ KCmdLineArgs.init (sys.argv, aboutData)
# Note that the argument for this method is a list
# of tuples
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
# instantiate TDEApplication - no other TQObject
# or TQWidget based classes can be instantiated
@@ -75,7 +75,7 @@ aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
# Pass the command line arguments and aboutData to
-# KCmdLineArgs - this is where KDE will look for
+# TDECmdLineArgs - this is where KDE will look for
# this information. The TDEApplication constructor
# used below *requires* the args are processed
diff --git a/templates/annotated/menuapp1.py b/templates/annotated/menuapp1.py
index d18ea00..faa8662 100644
--- a/templates/annotated/menuapp1.py
+++ b/templates/annotated/menuapp1.py
@@ -45,7 +45,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, i18n, KStdAccel, KIcon, KIconLoader
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n, KStdAccel, KIcon, KIconLoader
from tdeui import KMainWindow, KMessageBox
TOOLBAR_NEW = 1
@@ -136,7 +136,7 @@ class MainWin (KMainWindow):
# Let KDE generate a nifty help menu
# The KAboutData/KCmdLineArgs data from the main part of the program
# will be used to generate the About dialog
helpMenu = self.helpMenu ("")
@@ -247,7 +247,7 @@ class MainWin (KMainWindow):
# See athe minimal.py and basicapp.py templates for
# explantion of the basic app and main window setup
# The following data is passed to KCmdLineArgs, which in
# turn makes it available to the "about" box in the Help
# menu (when the Help menu is created as above)
@@ -260,9 +260,9 @@ aboutData = KAboutData ("", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
@@ -136,7 +136,7 @@ class MainWin (KMainWindow):
# Let KDE generate a nifty help menu
- # The KAboutData/KCmdLineArgs data from the main part of the program
+ # The KAboutData/TDECmdLineArgs data from the main part of the program
# will be used to generate the About dialog
helpMenu = self.helpMenu ("")
@@ -247,7 +247,7 @@ class MainWin (KMainWindow):
# See athe minimal.py and basicapp.py templates for
# explantion of the basic app and main window setup
-# The following data is passed to KCmdLineArgs, which in
+# The following data is passed to TDECmdLineArgs, which in
# turn makes it available to the "about" box in the Help
# menu (when the Help menu is created as above)